@@ -17,11 +17,11 @@
 #define QGSADVANCEDDIGITIZINGDOCK
 
 #include <QList>
+#include <QQueue>
 
 #include <memory>
 
 #include "ui_qgsadvanceddigitizingdockwidgetbase.h"
-#include "qgsadvanceddigitizingfloater.h"
 #include "qgis_gui.h"
 #include "qgis_sip.h"
 #include "qgsdockwidget.h"
@@ -61,20 +61,11 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
       AbsoluteAngle = 1, //!< Azimuth
       RelativeAngle = 2, //!< Also for parallel and perpendicular
       RelativeCoordinates = 4, //!< This corresponds to distance and relative coordinates
+      Distance = 8, //!< Distance
     };
     Q_DECLARE_FLAGS( CadCapacities, CadCapacity )
     Q_FLAG( CadCapacities )
 
-    /**
-     * Additional constraints which can be enabled
-     */
-    enum class AdditionalConstraint SIP_MONKEYPATCH_SCOPEENUM : int
-    {
-      NoConstraint,  //!< No additional constraint
-      Perpendicular, //!< Perpendicular
-      Parallel       //!< Parallel
-    };
-
     /**
      * Type of interaction to simulate when editing values from external widget
      * \note unstable API (will likely change)
@@ -88,7 +79,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
 
     /**
      * \ingroup gui
-     * \brief The CadConstraint is an abstract class for all basic constraints (angle/distance/x/y).
+     * \brief The CadConstraint is a class for all basic constraints (angle/distance/x/y).
      * It contains all values (locked, value, relative) and pointers to corresponding widgets.
      * \note Relative is not mandatory since it is not used for distance.
      */
@@ -184,6 +175,12 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
          */
         void setValue( double value, bool updateWidget = true );
 
+        /**
+         * Returns a localized formatted string representation of the value.
+         * \since QGIS 3.32
+         */
+        QString displayValue() const;
+
         /**
          * Toggle lock mode
          */
@@ -194,6 +191,40 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
          */
         void toggleRelative();
 
+        /**
+         * Returns the numeric precision (decimal places) to show in the associated widget.
+         *
+         * \see setPrecision()
+         * \since QGIS 3.22
+         */
+        int precision() const { return mPrecision; }
+
+        /**
+         * Sets the numeric precision (decimal places) to show in the associated widget.
+         *
+         * \see precision()
+         * \since QGIS 3.22
+         */
+        void setPrecision( int precision );
+
+        /**
+         * Returns the constraint type
+         * \since QGIS 3.32
+         */
+        Qgis::CadConstraintType cadConstraintType() const;
+
+        /**
+         * Sets the constraint type to \a constraintType
+         * \since QGIS 3.32
+         */
+        void setCadConstraintType( Qgis::CadConstraintType constraintType );
+
+        /**
+         * Sets the map canvas to \a mapCanvas
+         * \since QGIS 3.32
+         */
+        void setMapCanvas( QgsMapCanvas *mapCanvas );
+
       private:
         QLineEdit *mLineEdit = nullptr;
         QToolButton *mLockerButton = nullptr;
@@ -203,6 +234,9 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
         bool mRepeatingLock;
         bool mRelative;
         double mValue;
+        int mPrecision = 6;
+        Qgis::CadConstraintType mCadConstraintType = Qgis::CadConstraintType::Generic;
+        QgsMapCanvas *mMapCanvas = nullptr;
     };
 
     /**
@@ -227,8 +261,8 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     bool applyConstraints( QgsMapMouseEvent *e );
 
     /**
-     * align to segment for additional constraint.
-     * If additional constraints are used, this will determine the angle to be locked depending on the snapped segment.
+     * align to segment for between line constraint.
+     * If between line constraints are used, this will determine the angle to be locked depending on the snapped segment.
      * \since QGIS 3.0
      */
     bool alignToSegment( QgsMapMouseEvent *e, QgsAdvancedDigitizingDockWidget::CadConstraint::LockMode lockMode = QgsAdvancedDigitizingDockWidget::CadConstraint::HardLock );
@@ -250,14 +284,32 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     //! determines if CAD tools are enabled or if map tools behaves "nomally"
     bool cadEnabled() const { return mCadEnabled; }
 
+    /**
+     * Determines if Z or M will be enabled.
+     * \since QGIS 3.22
+     */
+    void switchZM( );
+
+    /**
+     * Sets whether Z is enabled
+     * \since QGIS 3.22
+     */
+    void setEnabledZ( bool enable );
+
+    /**
+     * Sets whether M is enabled
+     * \since QGIS 3.22
+     */
+    void setEnabledM( bool enable );
+
     //! construction mode is used to draw intermediate points. These points won't be given any further (i.e. to the map tools)
     bool constructionMode() const { return mConstructionMode; }
 
     /**
-     * Returns the additional constraints which are used to place
+     * Returns the between line constraints which are used to place
      * perpendicular/parallel segments to snapped segments on the canvas
      */
-    AdditionalConstraint additionalConstraint() const  { return mAdditionalConstraint; }
+    Qgis::BetweenLineConstraint betweenLineConstraint() const  { return mBetweenLineConstraint; }
     //! Returns the \a CadConstraint on the angle
     const CadConstraint *constraintAngle() const  { return mAngleConstraint.get(); }
     //! Returns the \a CadConstraint on the distance
@@ -266,15 +318,55 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     const CadConstraint *constraintX() const { return mXConstraint.get(); }
     //! Returns the \a CadConstraint on the Y coordinate
     const CadConstraint *constraintY() const { return mYConstraint.get(); }
+
+    /**
+     * Returns the \a CadConstraint on the Z coordinate
+     * \since QGIS 3.22
+     */
+    const CadConstraint *constraintZ() const { return mZConstraint.get(); }
+
+    /**
+     * Returns the \a CadConstraint on the M coordinate
+     * \since QGIS 3.22
+     */
+    const CadConstraint *constraintM() const { return mMConstraint.get(); }
     //! Returns TRUE if a constraint on a common angle is active
     bool commonAngleConstraint() const { return !qgsDoubleNear( mCommonAngleConstraint, 0.0 ); }
 
+    //! Returns the \a CadConstraint
+    const CadConstraint *constraintLineExtension() const { return mLineExtensionConstraint.get(); }
+
+    //! Returns on which side of the constraint line extension point, the line was created
+    Qgis::LineExtensionSide lineExtensionSide() const { return mSoftLockLineExtension; }
+
+    //! Returns the \a CadConstraint
+    const CadConstraint *constraintXyVertex() const { return mXyVertexConstraint.get(); }
+
+    //! Returns the X value of the X soft lock. The value is NaN is the constraint isn't magnetized to a line
+    double softLockX() const { return mSoftLockX; }
+
+    //! Returns the Y value of the Y soft lock. The value is NaN is the constraint isn't magnetized to a line
+    double softLockY() const { return mSoftLockY; }
+
     /**
      * Returns the point locator match
      * \since QGIS 3.4
      */
     QgsPointLocator::Match mapPointMatch() const { return mSnapMatch; }
 
+    /**
+     * Returns the snap matches whose vertices have been locked
+     * \since QGIS 3.26
+     */
+    QList< QgsPointLocator::Match > lockedSnapVertices() const { return mLockedSnapVertices; }
+
+    /**
+      * Removes all points from the locked snap vertex list
+      * \param force Clears the list even if the constraints that use it are still locked.
+      * \since QGIS 3.26
+      */
+    void clearLockedSnapVertices( bool force = true );
+
     /**
      * Removes all points from the CAD point list
      * \since QGIS 3.0
@@ -288,11 +380,17 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     void addPoint( const QgsPointXY &point );
 
     /**
-     * Remove previous point in the CAD point list
+     * Removes previous point in the CAD point list
      * \since QGIS 3.8
      */
     void removePreviousPoint();
 
+    /**
+     * Updates the current \a point in the CAD point list
+     * \since QGIS 3.30.2
+     */
+    void updateCurrentPoint( const QgsPoint &point );
+
     /**
      * Configures list of current CAD points
      *
@@ -306,22 +404,55 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * The last point.
      * Helper for the CAD point list. The CAD point list is the list of points
      * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
+     *
+     * \since QGIS 3.22
      */
-    QgsPointXY currentPoint( bool *exists  = nullptr ) const;
+    QgsPoint currentPointV2( bool *exists  = nullptr ) const;
+
+    /**
+     * Returns the last CAD point, in a map \a layer's coordinates.
+     *
+     * \since QGIS 3.22
+     */
+    QgsPoint currentPointLayerCoordinates( QgsMapLayer *layer ) const;
+
+    /**
+     * The last point.
+     * Helper for the CAD point list. The CAD point list is the list of points
+     * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
+     * \deprecated since QGIS 3.22. Use currentPointV2() instead.
+     */
+    Q_DECL_DEPRECATED QgsPointXY currentPoint( bool *exists  = nullptr ) const SIP_DEPRECATED { return currentPointV2( exists ); };
 
     /**
      * The previous point.
      * Helper for the CAD point list. The CAD point list is the list of points
      * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
      */
-    QgsPointXY previousPoint( bool *exists = nullptr ) const;
+    QgsPoint previousPointV2( bool *exists = nullptr ) const;
+
+    /**
+     * The previous point.
+     * Helper for the CAD point list. The CAD point list is the list of points
+     * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
+     * \deprecated since QGIS 3.22. Use previousPointV2() instead.
+     */
+    Q_DECL_DEPRECATED QgsPointXY previousPoint( bool *exists = nullptr ) const SIP_DEPRECATED { return previousPointV2( exists ); };
 
     /**
      * The penultimate point.
      * Helper for the CAD point list. The CAD point list is the list of points
      * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
      */
-    QgsPointXY penultimatePoint( bool *exists = nullptr ) const;
+    QgsPoint penultimatePointV2( bool *exists = nullptr ) const;
+
+    /**
+     * The penultimate point.
+     * Helper for the CAD point list. The CAD point list is the list of points
+     * currently digitized. It contains both  "normal" points and intermediate points (construction mode).
+     * \deprecated since QGIS 3.22. Use penultimatePointV2() instead.
+     */
+    Q_DECL_DEPRECATED QgsPointXY penultimatePoint( bool *exists = nullptr ) const SIP_DEPRECATED { return penultimatePointV2( exists ); };
 
     /**
      * The number of points in the CAD point helper list
@@ -380,6 +511,26 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void setY( const QString &value, WidgetSetMode mode );
 
+    /**
+    * Set the Z value on the widget.
+    * Can be used to set constraints by external widgets.
+    * \param mode What type of interaction to emulate
+    * \param value The value (as a QString, as it could be an expression)
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void setZ( const QString &value, WidgetSetMode mode );
+
+    /**
+    * Set the M value on the widget.
+    * Can be used to set constraints by external widgets.
+    * \param mode What type of interaction to emulate
+    * \param value The value (as a QString, as it could be an expression)
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void setM( const QString &value, WidgetSetMode mode );
+
     /**
     * Set the angle value on the widget.
     * Can be used to set constraints by external widgets.
@@ -400,7 +551,29 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void setDistance( const QString &value, WidgetSetMode mode );
 
+    /**
+     * Convenient method to get the Z value from the line edit wiget
+     * \since QGIS 3.22
+     */
+    double getLineZ( ) const;
 
+    /**
+     * Convenient method to get the M value from the line edit wiget
+     * \since QGIS 3.22
+     */
+    double getLineM( ) const;
+
+    /**
+     * Returns the capacities
+     * \since QGIS 3.26
+     */
+    CadCapacities capacities() const { return mCapacities; };
+
+    /**
+     * Returns the formatted label for common angle snapping option.
+     * \since QGIS 3.32
+     */
+    QString formatCommonAngleSnapping( double angle );
 
   signals:
 
@@ -421,8 +594,18 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      * when a constraint is toggled.
      *
      * \param point The last known digitizing point. Can be used to emulate a mouse event.
+     * \since QGIS 3.22
      */
-    void pointChanged( const QgsPointXY &point );
+    void pointChangedV2( const QgsPoint &point );
+
+    /**
+     * Sometimes a constraint may change the current point out of a mouse event. This happens normally
+     * when a constraint is toggled.
+     *
+     * \param point The last known digitizing point. Can be used to emulate a mouse event.
+     * \deprecated since QGIS 3.22. No longer used, will be removed in QGIS 4.0. Use pointChangedV2 instead.
+     */
+    Q_DECL_DEPRECATED void pointChanged( const QgsPointXY &point ) SIP_DEPRECATED;
 
     //! Signals for external widgets that need to update according to current values
 
@@ -451,6 +634,22 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void valueYChanged( const QString &value );
 
+    /**
+    * Emitted whenever the Z \a value changes (either the mouse moved, or the user changed the input).
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void valueZChanged( const QString &value );
+
+    /**
+    * Emitted whenever the M \a value changes (either the mouse moved, or the user changed the input).
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void valueMChanged( const QString &value );
+
     /**
     * Emitted whenever the angle \a value changes (either the mouse moved, or the user changed the input).
     * Could be used by widgets that must reflect the current advanced digitizing state.
@@ -467,6 +666,14 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void valueDistanceChanged( const QString &value );
 
+    /**
+    * Emitted whenever the bearing \a value changes.
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.32
+    */
+    void valueBearingChanged( const QString &value );
+
     /**
     * Emitted whenever the X parameter is \a locked.
     * Could be used by widgets that must reflect the current advanced digitizing state.
@@ -483,6 +690,22 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void lockYChanged( bool locked );
 
+    /**
+    * Emitted whenever the Z parameter is \a locked.
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void lockZChanged( bool locked );
+
+    /**
+    * Emitted whenever the M parameter is \a locked.
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void lockMChanged( bool locked );
+
     /**
     * Emitted whenever the angle parameter is \a locked.
     * Could be used by widgets that must reflect the current advanced digitizing state.
@@ -519,6 +742,26 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void relativeYChanged( bool relative );
 
+    /**
+    * Emitted whenever the Z parameter is toggled between absolute and relative.
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    *
+    * \param relative Whether the Z parameter is relative or not.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void relativeZChanged( bool relative );
+
+    /**
+    * Emitted whenever the M parameter is toggled between absolute and relative.
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    *
+    * \param relative Whether the M parameter is relative or not.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void relativeMChanged( bool relative );
+
     /**
     * Emitted whenever the angleX parameter is toggled between absolute and relative.
     * Could be used by widgets that must reflect the current advanced digitizing state.
@@ -529,6 +772,22 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void relativeAngleChanged( bool relative );
 
+    /**
+    * Emitted whenever the soft line extension parameter is \a locked.
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.26
+    */
+    void softLockLineExtensionChanged( bool locked );
+
+    /**
+    * Emitted whenever the soft x/y extension parameter is \a locked.
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.26
+    */
+    void softLockXyChanged( bool locked );
+
     // relativeDistanceChanged doesn't exist as distance is always relative
 
     /**
@@ -553,6 +812,28 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void enabledChangedY( bool enabled );
 
+    /**
+    * Emitted whenever the Z field is enabled or disabled. Depending on the context, some parameters
+    * do not make sense (e.g. you need a previous point to define a distance).
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    *
+    * \param enabled Whether the Z parameter is enabled or not.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void enabledChangedZ( bool enabled );
+
+    /**
+    * Emitted whenever the M field is enabled or disabled. Depending on the context, some parameters
+    * do not make sense (e.g. you need a previous point to define a distance).
+    * Could be used by widgets that must reflect the current advanced digitizing state.
+    *
+    * \param enabled Whether the M parameter is enabled or not.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void enabledChangedM( bool enabled );
+
     /**
     * Emitted whenever the angle field is enabled or disabled. Depending on the context, some parameters
     * do not make sense (e.g. you need a previous point to define a distance).
@@ -591,6 +872,22 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void focusOnYRequested();
 
+    /**
+    * Emitted whenever the Z field should get the focus using the shortcuts (Z).
+    * Could be used by widgets to capture the focus when a field is being edited.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void focusOnZRequested();
+
+    /**
+    * Emitted whenever the M field should get the focus using the shortcuts (M).
+    * Could be used by widgets to capture the focus when a field is being edited.
+    * \note unstable API (will likely change)
+    * \since QGIS 3.22
+    */
+    void focusOnMRequested();
+
     /**
     * Emitted whenever the angle field should get the focus using the shortcuts (A).
     * Could be used by widgets to capture the focus when a field is being edited.
@@ -607,14 +904,28 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     */
     void focusOnDistanceRequested();
 
+    /**
+    * Emitted whenever the snapping to common angle option changes, angle = 0 means that the functionality is disabled.
+    * \since QGIS 3.32
+    */
+    void valueCommonAngleSnappingChanged( double angle );
+
+    /**
+     * Emitted whenever the option to show common angle snapping in the floater changes.
+     * \note Not available in Python bindings
+     */
+    void commonAngleSnappingShowInFloaterChanged( bool enabled ) SIP_SKIP;
 
   private slots:
-    //! Sets the additional constraint by clicking on the perpendicular/parallel buttons
-    void additionalConstraintClicked( bool activated );
+    //! Sets the between line constraint by clicking on the perpendicular/parallel buttons
+    void betweenLineConstraintClicked( bool activated );
 
     //! lock/unlock a constraint and set its value
     void lockConstraint( bool activate = true );
 
+    //! lock/unlock a parameterless constraint
+    void lockParameterlessConstraint( bool activate = true );
+
     /**
      * Called when user has manually altered a constraint value. Any entered expressions will
      * be left intact
@@ -646,6 +957,12 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     void settingsButtonTriggered( QAction *action );
 
   private:
+
+    /**
+     * Returns the layer currently associated with the map tool using the dock widget.
+     */
+    QgsMapLayer *targetLayer() const;
+
     //! updates the UI depending on activation of the tools and clear points / release locks.
     void setCadEnabled( bool enabled );
 
@@ -655,8 +972,8 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      */
     void updateCapacity( bool updateUIwithoutChange = false );
 
-    //! defines the additional constraint to be used (no/parallel/perpendicular)
-    void lockAdditionalConstraint( AdditionalConstraint constraint );
+    //! defines the between line constraint to be used (no/parallel/perpendicular)
+    void lockBetweenLineConstraint( Qgis::BetweenLineConstraint constraint );
 
     /**
      * Returns the first snapped segment. Will try to snap a segment using all layers
@@ -665,10 +982,6 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
      */
     QList<QgsPointXY> snapSegmentToAllLayers( const QgsPointXY &originalMapPoint, bool *snapped = nullptr ) const;
 
-    //! update the current point in the CAD point list
-    void updateCurrentPoint( const QgsPointXY &point );
-
-
     /**
      * filters key press
      * \note called by eventFilter (filter on line edits), canvasKeyPressEvent (filter on map tool) and keyPressEvent (filter on dock)
@@ -688,7 +1001,7 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     CadConstraint *objectToConstraint( const QObject *obj ) const;
 
     //! Attempts to convert a user input value to double, either directly or via expression
-    double parseUserInput( const QString &inputValue, bool &ok ) const;
+    double parseUserInput( const QString &inputValue, const Qgis::CadConstraintType type, bool &ok ) const;
 
     /**
      * Updates a constraint value based on a text input.
@@ -699,7 +1012,15 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     void updateConstraintValue( CadConstraint *constraint, const QString &textValue, bool convertExpression = false );
 
     //! Updates values of constraints that are not locked based on the current point
-    void updateUnlockedConstraintValues( const QgsPointXY &point );
+    void updateUnlockedConstraintValues( const QgsPoint &point );
+
+
+    /**
+     * Adds or removes the snap match if it is already in the locked snap queue or not.
+     * \param snapMatch the snap match to add or remove.
+     * \param previouslySnap the previous snap match to avoid toggling the same match.
+     */
+    void toggleLockedSnapVertex( const QgsPointLocator::Match &snapMatch, QgsPointLocator::Match previouslySnap );
 
     QgsMapCanvas *mMapCanvas = nullptr;
     QgsAdvancedDigitizingCanvasItem *mCadPaintItem = nullptr;
@@ -723,11 +1044,18 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     std::unique_ptr< CadConstraint > mDistanceConstraint;
     std::unique_ptr< CadConstraint > mXConstraint;
     std::unique_ptr< CadConstraint > mYConstraint;
-    AdditionalConstraint mAdditionalConstraint;
+    std::unique_ptr< CadConstraint > mZConstraint;
+    std::unique_ptr< CadConstraint > mMConstraint;
+    std::unique_ptr< CadConstraint > mLineExtensionConstraint;
+    std::unique_ptr< CadConstraint > mXyVertexConstraint;
+    Qgis::BetweenLineConstraint mBetweenLineConstraint;
     double mCommonAngleConstraint; // if 0: do not snap to common angles
 
+    //! Flag that controls whether snapping to features has priority over common angle
+    bool mSnappingPrioritizeFeatures = false;
+
     // point list and current snap point / segment
-    QList<QgsPointXY> mCadPointList;
+    QList<QgsPoint> mCadPointList;
     QList<QgsPointXY> mSnappedSegment;
 
     bool mSessionActive = false;
@@ -736,16 +1064,34 @@ class GUI_EXPORT QgsAdvancedDigitizingDockWidget : public QgsDockWidget, private
     std::unique_ptr<QgsMessageBarItem> mErrorMessage;
 
     // UI
-    QMap< QAction *, double > mCommonAngleActions; // map the common angle actions with their angle values
+    QMap< double, QAction *> mCommonAngleActions; // map the common angle actions with their angle values
+    QAction *mLineExtensionAction;
+    QAction *mXyVertexAction;
 
     // Snap indicator
-
     QgsPointLocator::Match mSnapMatch;
-  private:
+    QgsPointLocator::Match mLastSnapMatch;
+
+    // Extra constraint context
+    Qgis::LineExtensionSide mSoftLockLineExtension;
+    double mSoftLockX;
+    double mSoftLockY;
+    QQueue< QgsPointLocator::Match > mLockedSnapVertices;
+
 #ifdef SIP_RUN
     //! event filter for line edits in the dock UI (angle/distance/x/y line edits)
     bool eventFilter( QObject *obj, QEvent *event );
 #endif
+    //! Convenient method to convert a 2D Point to a QgsPoint
+    QgsPoint pointXYToPoint( const QgsPointXY &point ) const;
+
+    QMenu *mCommonAngleActionsMenu = nullptr;
+    QMenu *mFloaterActionsMenu = nullptr;
+
+    static const QgsSettingsEntryBool *settingsCadSnappingPriorityPrioritizeFeature;
+
+    friend class TestQgsAdvancedDigitizing;
+    friend class TestQgsAdvancedDigitizingDockWidget;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS( QgsAdvancedDigitizingDockWidget::CadCapacities )
