@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.30.0-'s-Hertogenbosch"
-#define _QGIS_VERSION "3.30.0-'s-Hertogenbosch"
+#define VERSION "3.32.3-Lima"
+#define _QGIS_VERSION "3.32.3-Lima"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3300
+//#define VERSION_INT 3323
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 33000
-#define _QGIS_VERSION_INT 33000
-#define ABISYM(x) x ## 33000
+#define VERSION_INT 33203
+#define _QGIS_VERSION_INT 33203
+#define ABISYM(x) x ## 33203
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "'s-Hertogenbosch"
+#define RELEASE_NAME "Lima"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,12 +31,12 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr/local"
-#define CMAKE_SOURCE_DIR "/local/pobj/qgis-3.30.0/qgis-3.30.0"
+#define CMAKE_SOURCE_DIR "/usr/obj/ports/qgis-3.32.3/qgis-3.32.3"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
 #if !defined(QSCINTILLA_VERSION_STR)
-#define QSCINTILLA_VERSION_STR "2.13.3"
+#define QSCINTILLA_VERSION_STR "2.14.1"
 #endif
 
 #if defined( __APPLE__ )
@@ -46,13 +46,13 @@
 
 #define QT_PLUGINS_DIR "/usr/local/lib/qt5/plugins"
 
-#define PYTHON_VERSION "3.10.10"
+#define PYTHON_VERSION "3.10.13"
 #define PYTHON_VERSION_MAJOR "3"
 #define PYTHON_VERSION_MINOR "10"
-#define PYTHON_VERSION_PATCH "10"
+#define PYTHON_VERSION_PATCH "13"
 
 #define PROJ_VERSION_MAJOR 9
-#define PROJ_VERSION_MINOR 2
+#define PROJ_VERSION_MINOR 3
 #define PROJ_VERSION_PATCH 0
 
 /* #undef USING_NMAKE */
@@ -103,12 +103,12 @@
 #define HAVE_COPC
 
 #define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.5.2"
+#define PDAL_VERSION "2.5.6"
 #define PDAL_VERSION_MAJOR_INT 2
 #define PDAL_VERSION_MINOR_INT 5
 #define PDAL_VERSION_MAJOR "2"
 #define PDAL_VERSION_MINOR "5"
-#define PDAL_VERSION_MICRO "2"
+#define PDAL_VERSION_MICRO "6"
 
 #define ENABLE_TESTS
 
