@@ -836,8 +836,11 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
     QgsProjOperation operation() const;
 
     /**
-     * Returns whether axis is inverted (e.g., for WMS 1.3) for the CRS.
+     * Returns whether the axis order is inverted for the CRS compared to the order east/north (longitude/latitude).
+     * E.g. with WMS 1.3 the axis order for EPSG:4326 is north/east (latitude/longitude), i.e. inverted.
      * \returns TRUE if CRS axis is inverted
+     *
+     * \see axisOrdering()
      */
     bool hasAxisInverted() const;
 
@@ -1063,6 +1066,18 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      */
     static void pushRecentCoordinateReferenceSystem( const QgsCoordinateReferenceSystem &crs );
 
+    /**
+     * Removes a CRS from the list of recently used CRS.
+     * \since QGIS 3.32
+     */
+    static void removeRecentCoordinateReferenceSystem( const QgsCoordinateReferenceSystem &crs );
+
+    /**
+     * Cleans the list of recently used CRS.
+     * \since QGIS 3.32
+     */
+    static void clearRecentCoordinateReferenceSystems();
+
 #ifndef SIP_RUN
 
     /**
