@@ -60,8 +60,8 @@ class CORE_EXPORT QgsGeometryGeneratorSymbolLayer : public QgsSymbolLayer
     void stopFeatureRender( const QgsFeature &feature, QgsRenderContext &context ) override;
     bool usesMapUnits() const override;
     QColor color() const override;
-    QgsUnitTypes::RenderUnit outputUnit() const override;
-    void setOutputUnit( QgsUnitTypes::RenderUnit unit ) override;
+    Qgis::RenderUnit outputUnit() const override;
+    void setOutputUnit( Qgis::RenderUnit unit ) override;
     QgsMapUnitScale mapUnitScale() const override;
 
     QgsSymbolLayer *clone() const override SIP_FACTORY;
@@ -78,7 +78,7 @@ class CORE_EXPORT QgsGeometryGeneratorSymbolLayer : public QgsSymbolLayer
     /**
      * Gets the expression to generate this geometry.
      */
-    QString geometryExpression() const { return mExpression->expression(); }
+    QString geometryExpression() const;
 
     /**
      * Returns the unit for the geometry expression.
@@ -89,7 +89,7 @@ class CORE_EXPORT QgsGeometryGeneratorSymbolLayer : public QgsSymbolLayer
      * \see setUnits()
      * \since QGIS 3.22
      */
-    QgsUnitTypes::RenderUnit units() const { return mUnits; }
+    Qgis::RenderUnit units() const { return mUnits; }
 
     /**
      * Sets the \a units for the geometry expression.
@@ -100,7 +100,7 @@ class CORE_EXPORT QgsGeometryGeneratorSymbolLayer : public QgsSymbolLayer
      * \see units()
      * \since QGIS 3.22
      */
-    void setUnits( QgsUnitTypes::RenderUnit units ) { mUnits = units;}
+    void setUnits( Qgis::RenderUnit units ) { mUnits = units;}
 
     QgsSymbol *subSymbol() override { return mSymbol; }
 
@@ -128,7 +128,7 @@ class CORE_EXPORT QgsGeometryGeneratorSymbolLayer : public QgsSymbolLayer
      * \param points optional list of original points which are being rendered by the parent symbol (since QGIS 3.22)
      * \param rings optional list of original rings which are being rendered by the parent symbol (since QGIS 3.22)
      */
-    void render( QgsSymbolRenderContext &context, QgsWkbTypes::GeometryType geometryType = QgsWkbTypes::GeometryType::UnknownGeometry, const QPolygonF *points = nullptr, const QVector<QPolygonF> *rings = nullptr );
+    void render( QgsSymbolRenderContext &context, Qgis::GeometryType geometryType = Qgis::GeometryType::Unknown, const QPolygonF *points = nullptr, const QVector<QPolygonF> *rings = nullptr );
 
     void setColor( const QColor &color ) override;
 
@@ -161,7 +161,7 @@ class CORE_EXPORT QgsGeometryGeneratorSymbolLayer : public QgsSymbolLayer
      */
     Qgis::SymbolType mSymbolType;
 
-    QgsUnitTypes::RenderUnit mUnits = QgsUnitTypes::RenderMapUnits;
+    Qgis::RenderUnit mUnits = Qgis::RenderUnit::MapUnits;
 
     bool mRenderingFeature = false;
     bool mHasRenderedFeature = false;
