@@ -17,11 +17,12 @@
 #ifndef QGSLAYOUTVIEW_H
 #define QGSLAYOUTVIEW_H
 
-#include "qgis.h"
+#include "qgis_sip.h"
 #include "qgsprevieweffect.h" // for QgsPreviewEffect::PreviewMode
 #include "qgis_gui.h"
 #include "qgslayoutitempage.h"
 #include "qgslayoutaligner.h"
+#include "qgslayoutviewtool.h"
 #include <QPointer>
 #include <QGraphicsView>
 #include <QGraphicsRectItem>
@@ -29,7 +30,6 @@
 
 class QMenu;
 class QgsLayout;
-class QgsLayoutViewTool;
 class QgsLayoutViewToolTemporaryKeyPan;
 class QgsLayoutViewToolTemporaryKeyZoom;
 class QgsLayoutViewToolTemporaryMousePan;
@@ -37,10 +37,11 @@ class QgsLayoutRuler;
 class QgsLayoutViewMenuProvider;
 class QgsLayoutViewSnapMarker;
 class QgsLayoutReportSectionLabel;
+class QgsScreenHelper;
 
 /**
  * \ingroup gui
- * A graphical widget to display and interact with QgsLayouts.
+ * \brief A graphical widget to display and interact with QgsLayouts.
  *
  * QgsLayoutView manages the layout interaction tools and mouse/key events.
  *
@@ -49,6 +50,15 @@ class QgsLayoutReportSectionLabel;
 class GUI_EXPORT QgsLayoutView: public QGraphicsView
 {
 
+#ifdef SIP_RUN
+    SIP_CONVERT_TO_SUBCLASS_CODE
+    if ( qobject_cast<QgsLayoutView *>( sipCpp ) )
+      sipType = sipType_QgsLayoutView;
+    else
+      sipType = NULL;
+    SIP_END
+#endif
+
     Q_OBJECT
 
     Q_PROPERTY( QgsLayout *currentLayout READ currentLayout WRITE setCurrentLayout NOTIFY layoutSet )
@@ -123,20 +133,20 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
 
     /**
      * Sets whether a preview effect should be used to alter the view's appearance.
-     * \param enabled Set to true to enable the preview effect on the view.
+     * \param enabled Set to TRUE to enable the preview effect on the view.
      * \see setPreviewMode()
      */
     void setPreviewModeEnabled( bool enabled );
 
     /**
-     * Returns true if a preview effect is being used to alter the view's appearance.
+     * Returns TRUE if a preview effect is being used to alter the view's appearance.
      * \see setPreviewModeEnabled()
      */
     bool previewModeEnabled() const;
 
     /**
      * Sets the preview \a mode which should be used to modify the view's appearance. Preview modes are only used
-     * if previewModeEnabled() is true.
+     * if previewModeEnabled() is TRUE.
      * \see setPreviewModeEnabled()
      * \see previewMode()
      */
@@ -144,7 +154,7 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
 
     /**
      * Returns the preview mode which may be used to modify the view's appearance. Preview modes are only used
-     * if previewModeEnabled() is true.
+     * if previewModeEnabled() is TRUE.
      * \see setPreviewMode()
      * \see previewModeEnabled()
      */
@@ -180,7 +190,7 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
     void setMenuProvider( QgsLayoutViewMenuProvider *provider SIP_TRANSFER );
 
     /**
-    * Returns the provider for context menus. Returned value may be nullptr if no provider is set.
+    * Returns the provider for context menus. Returned value may be NULLPTR if no provider is set.
     * \see setMenuProvider()
     */
     QgsLayoutViewMenuProvider *menuProvider() const;
@@ -262,7 +272,7 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
     QList< QgsLayoutItem * > pasteItems( QPointF layoutPoint );
 
     /**
-     * Returns true if the current clipboard contains layout items.
+     * Returns TRUE if the current clipboard contains layout items.
      * \see pasteItems()
      */
     bool hasItemsInClipboard() const;
@@ -485,12 +495,12 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
     void toolSet( QgsLayoutViewTool *tool );
 
     /**
-     * Is emitted whenever the zoom level of the view is changed.
+     * Emitted whenever the zoom level of the view is changed.
      */
     void zoomLevelChanged();
 
     /**
-     * Is emitted when the mouse cursor coordinates change within the view.
+     * Emitted when the mouse cursor coordinates change within the view.
      * The \a layoutPoint argument indicates the cursor position within
      * the layout coordinate system.
      */
@@ -545,6 +555,8 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
     //! Zoom layout from a mouse wheel event
     void wheelZoom( QWheelEvent *event );
 
+    QgsScreenHelper *mScreenHelper = nullptr;
+
     QPointer< QgsLayoutViewTool > mTool;
 
     QgsLayoutViewToolTemporaryKeyPan *mSpacePanTool = nullptr;
@@ -579,7 +591,7 @@ class GUI_EXPORT QgsLayoutView: public QGraphicsView
 /**
  * \ingroup gui
  *
- * Interface for a QgsLayoutView context menu.
+ * \brief Interface for a QgsLayoutView context menu.
  *
  * Implementations of this interface can be made to allow QgsLayoutView
  * instances to provide custom context menus (opened upon right-click).
@@ -592,7 +604,7 @@ class GUI_EXPORT QgsLayoutViewMenuProvider
   public:
     virtual ~QgsLayoutViewMenuProvider() = default;
 
-    //! Returns a newly created menu instance (or null pointer on error)
+    //! Returns a newly created menu instance (or NULLPTR on error)
     virtual QMenu *createContextMenu( QWidget *parent SIP_TRANSFER, QgsLayout *layout, QPointF layoutPoint ) const = 0 SIP_FACTORY;
 };
 
@@ -603,7 +615,7 @@ class GUI_EXPORT QgsLayoutViewMenuProvider
 
 /**
  * \ingroup gui
- * A simple graphics item rendered as an 'x'.
+ * \brief A simple graphics item rendered as an 'x'.
  */
 class GUI_EXPORT QgsLayoutViewSnapMarker : public QGraphicsRectItem
 {
