@@ -144,6 +144,12 @@ class CORE_EXPORT QgsLegendRenderer
         //! Component size
         QSizeF size;
 
+        /**
+         * Starting indent for groups/subgroups nested in other groups/subgroups.
+         * This value is the sum of the indents of all parent groups/subgroups.
+         */
+        double indent = 0;
+
         /**
          * Horizontal offset for the symbol label.
          *
@@ -215,7 +221,7 @@ class CORE_EXPORT QgsLegendRenderer
      * Returns a list of component groups for the specified \a parentGroup, respecting the current layer's
      * splitting settings.
      */
-    QList<LegendComponentGroup> createComponentGroupList( QgsLayerTreeGroup *parentGroup, QgsRenderContext &context );
+    QList<LegendComponentGroup> createComponentGroupList( QgsLayerTreeGroup *parentGroup, QgsRenderContext &context, double indent = 0 );
 
     /**
      * Divides a list of component groups into columns, and sets the column index for each group in the list.
@@ -251,7 +257,7 @@ class CORE_EXPORT QgsLegendRenderer
      *
      * If \a context is NULLPTR, no painting will be attempted, but the required size will still be calculated and returned.
      */
-    QSizeF drawTitle( QgsRenderContext &context, double top, Qt::AlignmentFlag halignment = Qt::AlignLeft, double legendWidth = 0 );
+    QSizeF drawTitle( QgsRenderContext &context, double top, Qt::AlignmentFlag halignment = Qt::AlignLeft, double legendWidth = 0 ) const;
 
     /**
      * Draws an \a group and return its actual size, using the specified render \a context.
@@ -297,7 +303,7 @@ class CORE_EXPORT QgsLegendRenderer
 
 #endif
 
-    void widthAndOffsetForTitleText( const Qt::AlignmentFlag halignment, double legendWidth, double &width, double &offset );
+    void widthAndOffsetForTitleText( const Qt::AlignmentFlag halignment, double legendWidth, double &width, double &offset ) const;
 };
 
 #endif // QGSLEGENDRENDERER_H
