@@ -226,7 +226,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
                 ml.append( p->m() );
               }
 
-              if ( i == 0 && p->wkbType() == QgsWkbTypes::Point25D )
+              if ( i == 0 && p->wkbType() == Qgis::WkbType::Point25D )
                 is25D = true;
             }
             sipReleaseType( p, sipType_QgsPoint, state );
@@ -508,7 +508,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
      * does not have a z dimension
      * \see setZAt()
      */
-    double zAt( int index ) const
+    double zAt( int index ) const override
     {
       if ( index >= 0 && index < mZ.size() )
         return mZ.at( index );
@@ -527,7 +527,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
      *
      * \throws IndexError if no point with the specified index exists.
     */
-    double zAt( int index ) const;
+    double zAt( int index ) const override;
     % MethodCode
     const int count = sipCpp->numPoints();
     if ( a0 < -count || a0 >= count )
@@ -554,7 +554,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
      * does not have m values
      * \see setMAt()
      */
-    double mAt( int index ) const
+    double mAt( int index ) const override
     {
       if ( index >= 0 && index < mM.size() )
         return mM.at( index );
@@ -573,7 +573,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
      *
      * \throws IndexError if no point with the specified index exists.
     */
-    double mAt( int index ) const;
+    double mAt( int index ) const override;
     % MethodCode
     const int count = sipCpp->numPoints();
     if ( a0 < -count || a0 >= count )
@@ -911,7 +911,16 @@ class CORE_EXPORT QgsLineString: public QgsCurve
 
     QgsPoint centroid() const override;
 
+    /**
+     * Calculates the shoelace/triangle formula sum for the points in the linestring.
+     * If the linestring is closed (i.e. a polygon) then the polygon area is equal to the absolute value of the sum.
+     * Please note that the sum will be negative if the points are defined in clockwise order.
+     * Therefore, if you want to use the sum as an area (as the method name indicates) then you probably should use the absolute value,
+     * since otherwise a bug can be introduced (such as the bug fixed for github issue 49578)
+     * \see https://en.wikipedia.org/wiki/Shoelace_formula#Triangle_formula
+     */
     void sumUpArea( double &sum SIP_OUT ) const override;
+
     double vertexAngle( QgsVertexId vertex ) const override;
     double segmentLength( QgsVertexId startVertex ) const override;
     bool addZValue( double zValue = 0 ) override;
@@ -921,7 +930,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
     bool dropMValue() override;
     void swapXy() override;
 
-    bool convertTo( QgsWkbTypes::Type type ) override;
+    bool convertTo( Qgis::WkbType type ) override;
 
     bool transform( QgsAbstractGeometryTransformer *transformer, QgsFeedback *feedback = nullptr ) override;
     void scroll( int firstVertexIndex ) final;
@@ -939,7 +948,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
      */
     inline static const QgsLineString *cast( const QgsAbstractGeometry *geom )
     {
-      if ( geom && QgsWkbTypes::flatType( geom->wkbType() ) == QgsWkbTypes::LineString )
+      if ( geom && QgsWkbTypes::flatType( geom->wkbType() ) == Qgis::WkbType::LineString )
         return static_cast<const QgsLineString *>( geom );
       return nullptr;
     }
@@ -1066,7 +1075,7 @@ class CORE_EXPORT QgsLineString: public QgsCurve
      * \param type WKB type
      * \param wkb WKB representation of line geometry
      */
-    void fromWkbPoints( QgsWkbTypes::Type type, const QgsConstWkbPtr &wkb )
+    void fromWkbPoints( Qgis::WkbType type, const QgsConstWkbPtr &wkb )
     {
       mWkbType = type;
       importVerticesFromWkb( wkb );
