@@ -93,6 +93,12 @@ class GUI_EXPORT QgsMapToolCapture : public QgsMapToolAdvancedDigitizing
      */
     void setCurrentCaptureTechnique( Qgis::CaptureTechnique technique );
 
+    /**
+     * Returns the active capture technique
+     * \since QGIS 3.32
+     */
+    Qgis::CaptureTechnique currentCaptureTechnique() const { return mCurrentCaptureTechnique; }
+
     /**
      * Sets the current shape tool
      * \see QgsMapToolShapeRegistry
