@@ -37,6 +37,8 @@
  */
 class CORE_EXPORT QgsProcessingModelAlgorithm : public QgsProcessingAlgorithm
 {
+    Q_GADGET
+
   public:
 
     /**
@@ -55,7 +57,6 @@ class CORE_EXPORT QgsProcessingModelAlgorithm : public QgsProcessingAlgorithm
     QString shortHelpString() const override;
     QString shortDescription() const override;
     QString helpUrl() const override;
-    Flags flags() const override;
 
     bool canExecute( QString *errorMessage SIP_OUT = nullptr ) const override;
     QString asPythonCommand( const QVariantMap &parameters, QgsProcessingContext &context ) const override;
@@ -217,6 +218,15 @@ class CORE_EXPORT QgsProcessingModelAlgorithm : public QgsProcessingAlgorithm
      */
     void removeModelParameter( const QString &name );
 
+    /**
+     * Changes a model parameter's internal name from \a oldName to \a newName.
+     *
+     * This method will automatically update all model components to relink using the new name.
+     *
+     * \since QGIS 3.26
+     */
+    void changeParameterName( const QString &oldName, const QString &newName );
+
     /**
      * Returns TRUE if any child algorithms depend on the model parameter
      * with the specified \a name.
@@ -287,6 +297,41 @@ class CORE_EXPORT QgsProcessingModelAlgorithm : public QgsProcessingAlgorithm
      */
     void setParameterOrder( const QStringList &order );
 
+    /**
+     * Returns an ordered list of outputs for the model.
+     *
+     * \see setOutputOrder()
+     * \since QGIS 3.32
+     */
+    QList< QgsProcessingModelOutput > orderedOutputs() const;
+
+    /**
+     * Sets the \a order for sorting outputs for the model.
+     *
+     * The \a order list should consist of "output child algorithm id:output name" formatted strings corresponding to existing
+     * model outputs.
+     *
+     * \see orderedOutputs()
+     * \since QGIS 3.32
+     */
+    void setOutputOrder( const QStringList &order );
+
+    /**
+     * Returns the destination layer tree group name for outputs created by the model.
+     *
+     * \see setOutputGroup()
+     * \since QGIS 3.32
+     */
+    QString outputGroup() const;
+
+    /**
+     * Sets the destination layer tree \a group name for outputs created by the model.
+     *
+     * \see outputGroup()
+     * \since QGIS 3.32
+     */
+    void setOutputGroup( const QString &group );
+
     /**
      * Updates the model's parameter definitions to include all relevant destination
      * parameters as required by child algorithm ModelOutputs.
@@ -514,6 +559,34 @@ class CORE_EXPORT QgsProcessingModelAlgorithm : public QgsProcessingAlgorithm
      */
     void setDesignerParameterValues( const QVariantMap &values ) { mDesignerParameterValues = values; }
 
+    /**
+     * Given a child algorithm ID and output name, attempts to match it to a parameter definition from the overall model.
+     *
+     * \since QGIS 3.26
+     */
+    const QgsProcessingParameterDefinition *modelParameterFromChildIdAndOutputName( const QString &childId, const QString &childOutputName ) const;
+
+    /**
+     * Makes a name "safe", by replacing any non-alphanumeric characters with underscores.
+     *
+     * If \a capitalize is TRUE then the string will be converted to a camel case string.
+     *
+     * \since QGIS 3.26
+     */
+    static QString safeName( const QString &name, bool capitalize = false );
+
+#ifndef SIP_RUN
+
+    //! Internal model versions
+    enum class InternalVersion
+    {
+      Version1, //!< Created in < 3.26
+      Version2, //!< Created in >= 3.26
+    };
+    Q_ENUM( InternalVersion )
+
+#endif
+
   protected:
 
     QgsProcessingAlgorithm *createInstance() const override SIP_FACTORY;
@@ -522,6 +595,8 @@ class CORE_EXPORT QgsProcessingModelAlgorithm : public QgsProcessingAlgorithm
 
   private:
 
+    InternalVersion mInternalVersion = InternalVersion::Version2;
+
     QString mModelName;
     QString mModelGroup;
     QString mModelGroupId;
@@ -545,11 +620,13 @@ class CORE_EXPORT QgsProcessingModelAlgorithm : public QgsProcessingAlgorithm
     QMap< QString, QgsProcessingModelGroupBox > mGroupBoxes;
 
     QStringList mParameterOrder;
+    QStringList mOutputOrder;
+    QString mOutputGroup;
 
     void dependsOnChildAlgorithmsRecursive( const QString &childId, QSet<QString> &depends ) const;
     void dependentChildAlgorithmsRecursive( const QString &childId, QSet<QString> &depends, const QString &branch ) const;
 
-    QVariantMap parametersForChildAlgorithm( const QgsProcessingModelChildAlgorithm &child, const QVariantMap &modelParameters, const QVariantMap &results, const QgsExpressionContext &expressionContext, QString &error ) const;
+    QVariantMap parametersForChildAlgorithm( const QgsProcessingModelChildAlgorithm &child, const QVariantMap &modelParameters, const QVariantMap &results, const QgsExpressionContext &expressionContext, QString &error, const QgsProcessingContext *context = nullptr ) const;
 
     /**
      * Returns TRUE if an output from a child algorithm is required elsewhere in
